package org.apidesign.apifest08.test;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertNotNull;
import static org.apidesign.apifest08.test.Task1Test.CZK;
import static org.apidesign.apifest08.test.Task1Test.USD;

import java.util.Currency;

import org.apidesign.apifest08.currency.ConvertorFactory;
import org.apidesign.apifest08.currency.UnsupportedConversionException;
import org.junit.Test;


public class ConvertorFactoryTest {
	@Test(expected=NullPointerException.class)
	public void testNullSource()
	{
		ConvertorFactory.createConvertor(null, USD);
	}
	@Test(expected=NullPointerException.class)
	public void testNullDestination()
	{
		ConvertorFactory.createConvertor(CZK, null);
	}
	@Test(expected=IllegalArgumentException.class)
	public void testShortSource()
	{
		ConvertorFactory.createConvertor(Currency.getInstance("CZ"), USD);
	}
	@Test(expected=UnsupportedConversionException.class)
	public void testUnknownCombination()
	{
		ConvertorFactory.createConvertor(CZK, Currency.getInstance("ZAR"));
	}
	@Test
	public void testOk()
	{
		assertNotNull(ConvertorFactory.createConvertor(CZK, USD));
	}
	@Test
	public void testReverted()
	{
		assertEquals(ConvertorFactory.createConvertor(CZK, USD).revert(), ConvertorFactory.createConvertor(USD, CZK));
	}
}
