package org.apidesign.apifest08.currency;

import java.math.BigDecimal;
import java.util.Currency;

public abstract class Convertor {
    
   /**
    * Converts an amount to another amount according to a given currency.
    *  
	* @param from a source 
	* @param toCurrency a target currency
	* @return a converted amount
	* @throws ConversionException if the conversion fails
	* @throws UnsupportedConversionException if the conversion between a given currencies is not supported.
	*/
	public abstract Amount convert(Amount from, Currency toCurrency) throws ConversionException, UnsupportedConversionException;
	
	/**
	 * Converts an amount value between two currencies.
	 *  
	 * @param amount an amount
	 * @param fromCurrency an amount currency
	 * @param toCurrency to a target currency
	 * @return a converted amount value
	 * 
	 * @throws ConversionException if the conversion fails
	 * @throws UnsupportedConversionException if the conversion between a given currencies is not supported.
	 */
	public abstract Amount convert(BigDecimal amount, Currency fromCurrency, Currency toCurrency) throws ConversionException, UnsupportedConversionException;

}
