package org.apidesign.apifest08.test;

import java.util.Currency;

import junit.framework.TestCase;

import org.apidesign.apifest08.currency.Convertor;

/**
 * Finish the Convertor API, and then write bodies of methods inside of this class to match the given tasks. To fullfil
 * your task, use the API define in the <code>org.apidesign.apifest08.currency</code> package. Do not you reflection, or
 * other hacks as your code shall run without any runtime permissions.
 */
public class Task1Test extends TestCase {
  public Task1Test(String testName) {
    super(testName);
  }

  @Override
  protected void setUp() throws Exception {
  }

  @Override
  protected void tearDown() throws Exception {
  }

  /**
   * Create convertor that understands two currencies, CZK and USD. Make 1 USD == 17 CZK. Creation of the convertor
   * shall not require subclassing of any class or interface on the client side.
   * @return prepared convertor ready for converting USD to CZK and CZK to USD
   */
  public static Convertor createCZKtoUSD() {
    return Convertor.getConvertorInstance(Currency.getInstance("CZK"), Currency.getInstance("USD"));
  }

  /**
   * Create convertor that understands two currencies, CZK and SKK. Make 100 SKK == 80 CZK. Creation of the convertor
   * shall not require subclassing of any class or interface on the client side.
   * @return prepared convertor ready for converting SKK to CZK and CZK to SKK
   */
  public static Convertor createSKKtoCZK() {
    return Convertor.getConvertorInstance(Currency.getInstance("SKK"), Currency.getInstance("CZK"));
  }

  /**
   * Use the convertor from <code>createCZKtoUSD</code> method and do few conversions with it.
   */
  public void testCurrencyCZKUSD() throws Exception {
    Convertor c = createCZKtoUSD();

    // convert $5 to CZK using c:
    double result = c.convert(5, Currency.getInstance("USD"));
    assertEquals("Result is not 85 CZK", 85.0, result);

    // convert $8 to CZK
    result = c.convert(8, Currency.getInstance("USD"));
    assertEquals("Result is not 136 CZK", 136.0, result);

    // convert 1003CZK to USD
    result = c.convert(1003, Currency.getInstance("CZK"));
    assertEquals("Result is not 59 USD", 59.0, result);
  }

  /**
   * Use the convertor from <code>createSKKtoCZK</code> method and do few conversions with it.
   */
  public void testCurrencySKKCZK() throws Exception {
    Convertor c = createSKKtoCZK();

    // convert 16CZK using c:
    double result = c.convert(16, Currency.getInstance("CZK"));
    assertEquals("Result is not 20 SKK", 20.0, result);

    // convert 500SKK to CZK
    result = c.convert(500, Currency.getInstance("SKK"));
    assertEquals("Result is not 400 CZK", 400.0, result);
  }
}
